@@ -1,8 +1,8 @@
 use std::net::IpAddr;
 use std::path::PathBuf;
 
+use actix_web::http::header::{HeaderMap, HeaderName, HeaderValue};
 use clap::{Parser, ValueEnum, ValueHint};
-use http::header::{HeaderMap, HeaderName, HeaderValue};
 
 use crate::auth;
 use crate::listing::{SortingMethod, SortingOrder};
@@ -162,7 +162,7 @@ pub struct CliArgs {
     /// The provided path is not a physical file system path. Instead, it's relative to the serve
     /// dir. For instance, if the serve dir is '/home/hello', set this to '/upload' to allow
     /// uploading to '/home/hello/upload'.
-    /// When specified via environment variable, a path always neesd to the specified.
+    /// When specified via environment variable, a path always needs to be specified.
     #[arg(short = 'u', long = "upload-files", value_hint = ValueHint::FilePath, num_args(0..=1), value_delimiter(','), env = "MINISERVE_ALLOWED_UPLOAD_DIR")]
     pub allowed_upload_dir: Option<Vec<PathBuf>>,
 
@@ -235,7 +235,12 @@ pub struct CliArgs {
     #[arg(short = 't', long = "title", env = "MINISERVE_TITLE")]
     pub title: Option<String>,
 
-    /// Set custom header for responses
+    /// Inserts custom headers into the responses. Specify each header as a 'Header:Value' pair.
+    /// This parameter can be used multiple times to add multiple headers.
+    ///
+    /// Example:
+    /// --header "Header1:Value1" --header "Header2:Value2"
+    /// (If a header is already set or previously inserted, it will not be overwritten.)
     #[arg(
         long = "header",
         value_parser(parse_header),
