@@ -52,9 +52,8 @@ fn main() -> Result<()> {
 
     let miniserve_config = MiniserveConfig::try_from_args(args)?;
 
-    run(miniserve_config).map_err(|e| {
+    run(miniserve_config).inspect_err(|e| {
         errors::log_error_chain(e.to_string());
-        e
     })?;
 
     Ok(())
@@ -228,7 +227,7 @@ async fn run(miniserve_config: MiniserveConfig) -> Result<(), StartupError> {
 
         #[cfg(feature = "tls")]
         let srv = match &miniserve_config.tls_rustls_config {
-            Some(tls_config) => srv.listen_rustls(listener, tls_config.clone()),
+            Some(tls_config) => srv.listen_rustls_0_23(listener, tls_config.clone()),
             None => srv.listen(listener),
         };
 
