@@ -1,6 +1,6 @@
 use std::time::SystemTime;
 
-use actix_web::http::StatusCode;
+use actix_web::http::{StatusCode, Uri};
 use chrono::{DateTime, Local};
 use chrono_humanize::Humanize;
 use clap::{crate_name, crate_version, ValueEnum};
@@ -9,7 +9,6 @@ use fast_qr::{
     qr::QRCodeError,
     QRBuilder,
 };
-use http::Uri;
 use maud::{html, Markup, PreEscaped, DOCTYPE};
 use strum::{Display, IntoEnumIterator};
 
@@ -59,7 +58,7 @@ pub fn page(
             {
                 div.toolbar_box_group {
                     @if conf.file_upload {
-                        div.form {
+                        div.drag-form {
                             div.form_title {
                                 h1 { "Drop your file here to upload it" }
                             }
@@ -118,7 +117,7 @@ pub fn page(
                                     }
                                 }
                             }
-                            @if conf.mkdir_enabled {
+                            @if conf.mkdir_enabled && upload_allowed {
                                 div.toolbar_box {
                                     form id="mkdir" action=(mkdir_action) method="POST" enctype="multipart/form-data" {
                                         p { "Specify a directory name to create" }
